==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property enableDefaultValidation
 * @property resourceTypesWithCustomValidation
 */
public data class ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs(
    public val enableDefaultValidation: Output<Boolean>? = null,
    public val resourceTypesWithCustomValidation: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs.builder()
            .enableDefaultValidation(enableDefaultValidation?.applyValue({ args0 -> args0 }))
            .resourceTypesWithCustomValidation(
                resourceTypesWithCustomValidation?.applyValue({ args0 ->
                    args0.map({ args0 -> args0 })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgsBuilder
internal constructor() {
    private var enableDefaultValidation: Output<Boolean>? = null

    private var resourceTypesWithCustomValidation: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("ypsuahredwwvmeqy")
    public suspend fun enableDefaultValidation(`value`: Output<Boolean>) {
        this.enableDefaultValidation = value
    }

    /**
     * @param value
     */
    @JvmName("mkjvyiejnrnnvmrl")
    public suspend fun resourceTypesWithCustomValidation(`value`: Output<List<String>>) {
        this.resourceTypesWithCustomValidation = value
    }

    @JvmName("tmhnxhxuputaycld")
    public suspend fun resourceTypesWithCustomValidation(vararg values: Output<String>) {
        this.resourceTypesWithCustomValidation = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("votouyfgubrsygtc")
    public suspend fun resourceTypesWithCustomValidation(values: List<Output<String>>) {
        this.resourceTypesWithCustomValidation = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("eaxdtmgfemefwnfj")
    public suspend fun enableDefaultValidation(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableDefaultValidation = mapped
    }

    /**
     * @param value
     */
    @JvmName("desljacsqetueuug")
    public suspend fun resourceTypesWithCustomValidation(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceTypesWithCustomValidation = mapped
    }

    /**
     * @param values
     */
    @JvmName("qosuhosfiocfqoyk")
    public suspend fun resourceTypesWithCustomValidation(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceTypesWithCustomValidation = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs =
        ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs(
            enableDefaultValidation = enableDefaultValidation,
            resourceTypesWithCustomValidation = resourceTypesWithCustomValidation,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property enableDefaultValidation
 * @property resourceTypesWithCustomValidation
 */
public data class ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs(
    public val enableDefaultValidation: Output<Boolean>? = null,
    public val resourceTypesWithCustomValidation: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs.builder()
            .enableDefaultValidation(enableDefaultValidation?.applyValue({ args0 -> args0 }))
            .resourceTypesWithCustomValidation(
                resourceTypesWithCustomValidation?.applyValue({ args0 ->
                    args0.map({ args0 -> args0 })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgsBuilder
internal constructor() {
    private var enableDefaultValidation: Output<Boolean>? = null

    private var resourceTypesWithCustomValidation: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("iaxeunrpbropmqmd")
    public suspend fun enableDefaultValidation(`value`: Output<Boolean>) {
        this.enableDefaultValidation = value
    }

    /**
     * @param value
     */
    @JvmName("kvjhkxqdwrfbcygw")
    public suspend fun resourceTypesWithCustomValidation(`value`: Output<List<String>>) {
        this.resourceTypesWithCustomValidation = value
    }

    @JvmName("iqblebjonhcojoam")
    public suspend fun resourceTypesWithCustomValidation(vararg values: Output<String>) {
        this.resourceTypesWithCustomValidation = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("sxcikcnquqpydcep")
    public suspend fun resourceTypesWithCustomValidation(values: List<Output<String>>) {
        this.resourceTypesWithCustomValidation = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("yavmonihvsudlgvk")
    public suspend fun enableDefaultValidation(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableDefaultValidation = mapped
    }

    /**
     * @param value
     */
    @JvmName("tgwscojkfoehvysu")
    public suspend fun resourceTypesWithCustomValidation(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceTypesWithCustomValidation = mapped
    }

    /**
     * @param values
     */
    @JvmName("xjwynccpqqofpqpy")
    public suspend fun resourceTypesWithCustomValidation(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceTypesWithCustomValidation = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs =
        ResourceTypeRegistrationPropertiesCheckNameAvailabilitySpecificationsArgs(
            enableDefaultValidation = enableDefaultValidation,
            resourceTypesWithCustomValidation = resourceTypesWithCustomValidation,
        )
}
